summaryrefslogtreecommitdiff
path: root/gtk/gtkobject.h
diff options
context:
space:
mode:
authorTim Janik <timj@src.gnome.org>1998-02-21 13:33:20 +0000
committerTim Janik <timj@src.gnome.org>1998-02-21 13:33:20 +0000
commita8d6f14c2db9e4166d8b10d2974e7ad457553310 (patch)
tree5c08e6063d12dd09dbfc12ff40fdb2b27887b6c3 /gtk/gtkobject.h
parentf97dd05d5a72f8a01281875582a7a74e19548fff (diff)
downloadgtk+-a8d6f14c2db9e4166d8b10d2974e7ad457553310.tar.gz
added the sequential argument number to gtk_object_query_args.
-timj
Diffstat (limited to 'gtk/gtkobject.h')
-rw-r--r--gtk/gtkobject.h13
1 files changed, 7 insertions, 6 deletions
diff --git a/gtk/gtkobject.h b/gtk/gtkobject.h
index bf25c01988..8c2020a20c 100644
--- a/gtk/gtkobject.h
+++ b/gtk/gtkobject.h
@@ -78,7 +78,7 @@ enum
GTK_RESERVED_2 = 1 << 3
};
-/* GtkArg access bits for gtk_object_add_arg_type
+/* GtkArg flag bits for gtk_object_add_arg_type
*/
enum
{
@@ -246,19 +246,20 @@ void gtk_object_setv (GtkObject *object,
/* Allocate a GtkArg array of size nargs that hold the
* names and types of the args that can be used with
* gtk_object_set/gtk_object_get. if (acess_masks!=NULL),
* (*access_mask) will be set to point to a newly allocated
* guint array that holds the access masks of the args.
* It is the callers response to do a
* g_free (returned_args); g_free (*acess_masks).
*/
GtkArg* gtk_object_query_args (GtkType class_type,
- guint **acess_masks,
+ guint32 **arg_flags,
+ guint **seq_ids,
guint *nargs);
void gtk_object_add_arg_type (const gchar *arg_name,
GtkType arg_type,
- guint access_mask,
+ guint arg_flags,
guint arg_id);
GtkType gtk_object_get_arg_type (const gchar *arg_name);
@@ -246,19 +246,20 @@ void gtk_object_setv (GtkObject *object,
/* Allocate a GtkArg array of size nargs that hold the
* names and types of the args that can be used with
- * gtk_object_set/gtk_object_get. if (acess_masks!=NULL),
- * (*access_mask) will be set to point to a newly allocated
- * guint array that holds the access masks of the args.
+ * gtk_object_set/gtk_object_get. if (arg_flags!=NULL),
+ * (*arg_flags) will be set to point to a newly allocated
+ * guint array that holds the flags of the args.
* It is the callers response to do a
* g_free (returned_args); g_free (*acess_masks).